---
title: Understanding different parts of Solara
description: Solara is made of two main components, the bulk of the Solara package with UI elements that can be used together with Jupyter, and Solara server, which
    allows for these UI elements to be used in standalone apps and dashboards
---
# Solara

Solara combines [ipywidgets](./ipywidgets), [reacton](./reacton) and puts it into a opinionated framework to make web apps with a focus on data (data apps for short).

Solara consists of two main parts

## Solara-ui

A set of opinionated react components and hooks that allow you to build web apps and data apps faster.

## Solara-server

A web framework for deploying web apps or data apps in production. Opinionated about pages and routing.
